autowisp.database.data_model.image_type module — AutoWISP documentation

# autowisp.database.data_model.image_type module

## Class Inheritance Diagram

Define the image type table for the pipeline

class autowisp.database.data_model.image_type.ImageType(**kwargs)

  Bases: `DataModelBase`

  The table describing the different image types.

  description

    The description of the image type

  id

    A unique identifier for each row.

  image
  name

    The image type name

  timestamp

    When record was last changed